Exception: Ace::Hitl::Lifecycle::PermissionError
- Defined in:
- lib/ace/hitl/lifecycle/errors.rb
Overview
The operation requires an identity the caller does not have (root-only host-broker operations, foreign-requester answers).
The operation requires an identity the caller does not have (root-only host-broker operations, foreign-requester answers).